@@ -10,7 +10,7 @@ module Database.Redis.Core (
     auth, select
 ) where
 
-import Prelude hiding (catch)
+import Prelude
 import Control.Applicative
 import Control.Monad.Reader
 import qualified Data.ByteString as B
@@ -131,7 +131,7 @@ data ConnectInfo = ConnInfo
     --   smallest acceptable value is 0.5 seconds. If the @timeout@ value in
     --   your redis.conf file is non-zero, it should be larger than
     --   'connectMaxIdleTime'.
-    }
+    } deriving Show
 
 -- |Default information for connecting:
 --
